import { Component, OnInit } from '@angular/core';
import { ReviewManagementService } from 'app/admin/review-management/review-management.service';
import { Review } from 'app/admin/review-management/review.model';
import { ReviewRequest } from 'app/admin/review-management/reviewRequest.model';
import { UserManagementService } from 'app/admin/user-management/service/user-management.service';
import { User } from 'app/admin/user-management/user-management.model';
import { Account } from 'app/core/auth/account.model';
import { AccountService } from 'app/core/auth/account.service';
import { SearchService } from 'app/search/service/search-service';
import { Exercise, searchResultToExercise } from 'app/shared/model/exercise.model';
import { SearchResultsDTO } from 'app/shared/model/search/search-results-dto.model';

@Component({
  selector: 'jhi-peer-reviewing',
  templateUrl: './peer-reviewing.component.html',
  styleUrls: ['./peer-reviewing.component.scss'],
})
export class PeerReviewingComponent implements OnInit {
  isChecked = false;
  currentAccount: Account | null = null;
  user: User | null = null;
  results: Exercise[] = [];
  selectedExercise: Exercise | undefined;
  reviews: Review[] = [];

  constructor(
    private userService: UserManagementService,
    private accountService: AccountService,
    private searchService: SearchService,
    private reviewManagementService: ReviewManagementService
  ) {}

  ngOnInit(): void {
    this.accountService.identity().subscribe(account => (this.currentAccount = account));
    this.getUserFromLogin();
    this.searchForExercises();
    this.loadAll();
  }

  getUserFromLogin(): void {
    if (this.currentAccount != null && this.currentAccount.login != null) {
      this.userService.find(this.currentAccount?.login).subscribe(val => {
        this.user = val;
      });
    }
  }

  loadAll(): void {
    this.reviewManagementService.getAllByUser().subscribe(reviews => {
      this.reviews = reviews;
    });
  }

  setReviewerStatusForLogin(): void {
    if (this.user != null && this.currentAccount != null && this.user.login == this.currentAccount.login) {
      this.userService.updateReviewerStatus(!this.user.reviewingEnabled).subscribe();
    }
  }

  searchForExercises(): void {
    if (this.currentAccount) {
      this.searchService.getResultsForAuthor('michael.breu@uibk.ac.at').subscribe(
        (data: SearchResultsDTO) => {
          const searchResults = data.searchResult.map(searchResultToExercise);
          this.results = this.results.concat(searchResults);
        },
        () => alert('Search failed')
      );
    }
  }

  shareExercise(exercise: Exercise) {
    this.selectedExercise = exercise;
  }

  requestReview(): void {
    if (this.currentAccount) {
      this.searchService.requestReview(new ReviewRequest(this.selectedExercise!.title, [this.currentAccount.email])).subscribe();
    }
  }

  deleteReview(review: Review) {
    this.reviewManagementService.delete(review.id!).subscribe(() => this.loadAll());
  }
}
